| Title: | Selecting Auxiliary Variables in Small Area Estimation (SAE) Model |
|---|---|
| Description: | Select best combination of auxiliary variables with certain criterion. |
| Authors: | Azka Ubaidillah [aut], Sheerin Dahwan Aziz [aut, cre] |
| Maintainer: | Sheerin Dahwan Aziz <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-05-18 07:38:28 UTC |
| Source: | https://github.com/cran/saeBest |
Select best combination of auxiliary variables with certain criterion
eblupBest(y, x, vardir, criterion = "AIC", data)eblupBest(y, x, vardir, criterion = "AIC", data)
y |
name of response variable |
x |
vector of auxiliary variables' name |
vardir |
name of variance direct |
criterion |
"loglike","AIC", "BIC", and "KIC" (default = "AIC") |
data |
input dataset |
an EBLUP-FH model with best auxiliary variables and the dataset
library(saeBest) example = eblupBest(y = "y", x = c("x1","x2","x3"), vardir = "var",data = data)library(saeBest) example = eblupBest(y = "y", x = c("x1","x2","x3"), vardir = "var",data = data)