Welcome to ClientVPS Mirrors

Help for package saeBest
Type: Package
Title: Selecting Auxiliary Variables in Small Area Estimation (SAE) Model
Version: 0.1.0
Imports: sae
Author: Azka Ubaidillah [aut], Sheerin Dahwan Aziz [aut, cre]
Maintainer: Sheerin Dahwan Aziz <sheerindahwan@gmail.com>
Description: Select best combination of auxiliary variables with certain criterion.
License: GPL-3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.1.2
Depends: R (≥ 2.10)
NeedsCompilation: no
Packaged: 2021-12-07 08:24:08 UTC; Sheerin
Repository: CRAN
Date/Publication: 2021-12-07 11:00:02 UTC

Dataset

Description

Dataset

Usage

data(data)

Format

An object of class


Selecting Auxiliary Variables in Small Area Estimation (SAE) Model

Description

Select best combination of auxiliary variables with certain criterion

Usage

eblupBest(y, x, vardir, criterion = "AIC", data)

Arguments

y

name of response variable

x

vector of auxiliary variables' name

vardir

name of variance direct

criterion

"loglike","AIC", "BIC", and "KIC" (default = "AIC")

data

input dataset

Value

an EBLUP-FH model with best auxiliary variables and the dataset

Examples

library(saeBest)
example = eblupBest(y = "y", x = c("x1","x2","x3"), vardir = "var",data = data)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.